View Source Machete.Assertions (Machete v0.3.1)
Macros for use within the context of ExUnit tests, to provide ~> awareness to assert/1 and
refute/1 macros. Because macros cannot be defined in multiple modules, proper use of this
module requires the user to take ExUnit.Assertions' version of assert/1 and refute/1 out
of scope, and to allow this module's versions of those macros to call through to
ExUnit.Assertions' version for conditions other than ~>. See Machete.__using__/1 for
details.
Summary
Functions
A custom implementation of the assert/1 macro to provide support for useful errors on ~>
mismatches; all other patterns are passed through to ExUnit.Assertions.assert/1
A custom implementation of the refute/1 macro to provide support for useful errors on ~>
mismatches; all other patterns are passed through to ExUnit.Assertions.refute/1
Functions
A custom implementation of the assert/1 macro to provide support for useful errors on ~>
mismatches; all other patterns are passed through to ExUnit.Assertions.assert/1
A custom implementation of the refute/1 macro to provide support for useful errors on ~>
mismatches; all other patterns are passed through to ExUnit.Assertions.refute/1